@@ -6,4 +6,8 @@ fn main() {
 
     let vec = pt.translate_as_slice(content.clone());
     println!("{:?}", vec);
+
+    let pt2 = pinyin_translator::PinyinTranslator::new();
+    let result = pt2.unmark_translate("下面是一段多音分词歧义测试，这个人无伤无臭味。".to_string());
+    println!("{}", result);
 }
\ No newline at end of file
